pub struct HttpRelayBuilder(/* private fields */);Expand description
Builder for HttpRelay.
Implementations
Sourceimpl HttpRelayBuilder
impl HttpRelayBuilder
Sourcepub fn bind_address(self, addr: IpAddr) -> Self
pub fn bind_address(self, addr: IpAddr) -> Self
Configure the address to bind to (default: 127.0.0.1).
Sourcepub fn link_timeout(self, timeout: Duration) -> Self
pub fn link_timeout(self, timeout: Duration) -> Self
Configure the timeout for link endpoints (default: 10 minutes). This is how long producers wait for consumers (and vice versa).
Sourcepub fn inbox_timeout(self, timeout: Duration) -> Self
pub fn inbox_timeout(self, timeout: Duration) -> Self
Configure the timeout for inbox long-poll endpoints (default: 25 seconds). Shorter than the default request timeout to avoid proxy timeouts.
Sourcepub fn inbox_cache_ttl(self, ttl: Duration) -> Self
pub fn inbox_cache_ttl(self, ttl: Duration) -> Self
Configure the TTL for inbox messages (default: 5 minutes). Messages persist for this duration after being sent.
Sourcepub fn max_body_size(self, size: usize) -> Self
pub fn max_body_size(self, size: usize) -> Self
Configure the maximum request body size (default: 2KB).
Sourcepub fn max_entries(self, max: usize) -> Self
pub fn max_entries(self, max: usize) -> Self
Configure the maximum entries in the waiting list (default: 10000). When this limit is reached, oldest entries are evicted.
Sourcepub fn persist_db(self, path: Option<PathBuf>) -> Self
pub fn persist_db(self, path: Option<PathBuf>) -> Self
Configure the path to SQLite database for persistent storage. If not specified, uses in-memory storage (data lost on restart).